![](https://img.shields.io/pypi/v/crowdcent-challenge.png)
![Python Version](https://img.shields.io/badge/dynamic/toml?url=https://raw.githubusercontent.com/crowdcent/crowdcent-challenge/master/pyproject.toml&query=%24.project%5B%22requires-python%22%5D&label=python&color=blue)
![](https://img.shields.io/github/contributors/crowdcent/crowdcent-challenge.png)
[![uv](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/uv/main/assets/badge/v0.json)](https://github.com/astral-sh/uv)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
![](https://img.shields.io/codecov/c/gh/crowdcent/crowdcent-challenge/master)
![](https://img.shields.io/pypi/dm/crowdcent-challenge)

# CrowdCent Challenge
The CrowdCent Challenge is an open data science competition. This documentation is currently being updated. Please check back soon for detailed information about the challenge rules and format.

**Documentation**: [docs.crowdcent.com](https://docs.crowdcent.com)


## Have Questions?
If you need immediate assistance, please email us at info@crowdcent.com or join our [Discord server](https://discord.gg/crowdcent).